<!-- warning: Please don't edit this file. It was automatically generated. -->

# winrt-Windows.Media.DialProtocol

Windows Runtime (WinRT) APIs for for the `Windows.Media.DialProtocol` namespace.

This package provides the `winrt.windows.media.dialprotocol` module.
